resetBoundary property
Resets the error boundary, clearing any error state.
An optional argument can be passed that will be forwarded to the ErrorBoundary.onReset callback.
Implementation
final void Function([Object? arg]) resetBoundary;
Resets the error boundary, clearing any error state.
An optional argument can be passed that will be forwarded to the ErrorBoundary.onReset callback.
final void Function([Object? arg]) resetBoundary;