ErrorFallbackBuilder typedef

ErrorFallbackBuilder = Widget Function(BuildContext context, Object error, void resetErrorBoundary([Object? arg]))

A builder function for creating fallback UI when an error is caught.

Parameters:

  • context: The build context for creating widgets.
  • error: The error object that was caught.
  • resetErrorBoundary: A function to reset the error boundary state, optionally passing an argument that will be forwarded to ErrorBoundary.onReset.

Returns a widget to display as the fallback UI when an error occurs.

Implementation

typedef ErrorFallbackBuilder =
    Widget Function(
      BuildContext context,
      Object error,
      void Function([Object? arg]) resetErrorBoundary,
    );